@@ -102,9 +102,9 @@ def test_tuple_collector(recorder_setup: CollectionsRecorder) -> None:
     stream = io.StringIO(TEST_TUPLE_ADDRESSES)
     collector = TupleCollector(recorder=recorder)
     collector.collect(stream)
-    assert recorder.asn_counter == Counter({None: 4, 64496: 6, 64497: 1337})
+    assert recorder.asn_counter == Counter({None: 4, 64496: 6.9, 64497: 1337.3})
     assert recorder.prefix_counter == Counter(
-        {None: 4, "192.0.2.0/24": 6, "2001:db8:1::/48": 1337, "2001:db8::/48": 0}
+        {None: 4, "192.0.2.0/24": 6.9, "2001:db8:1::/48": 1337.3, "2001:db8::/48": 0}
     )
 
 
